@@ -57,7 +57,7 @@ panel_applet_set_dnd_enabled (AppletInfo *info,
 	case PANEL_OBJECT_LAUNCHER:
 		panel_launcher_set_dnd_enabled (info->data, dnd_enabled);
 		break;
-	case PANEL_OBJECT_BONOBO:
+	case PANEL_OBJECT_APPLET:
 		break;
 	case PANEL_OBJECT_LOGOUT:
 	case PANEL_OBJECT_LOCK:
@@ -194,7 +194,7 @@ panel_applet_locked_change_notify (GConfClient *client,
 
 	panel_applet_toggle_locked (info);
 
-	if (info->type == PANEL_OBJECT_BONOBO)
+	if (info->type == PANEL_OBJECT_APPLET)
 		panel_applet_frame_sync_menu_state (PANEL_APPLET_FRAME (info->widget));
 	else
 		panel_applet_recreate_menu (info);
@@ -268,7 +268,7 @@ applet_callback_callback (GtkWidget      *widget,
 			PANEL_MENU_BAR (menu->info->widget), menu->name);
 		break;
 
-	case PANEL_OBJECT_BONOBO:
+	case PANEL_OBJECT_APPLET:
 		/*
 		 * Applet's menu's are handled differently
 		 */
@@ -607,7 +607,7 @@ panel_applet_position_menu (GtkMenu   *menu,
 	gdk_window_get_origin (applet->window, &menu_x, &menu_y);
 	gtk_widget_get_pointer (applet, &pointer_x, &pointer_y);
 
-	if (GTK_WIDGET_NO_WINDOW (applet)) {
+	if (!gtk_widget_get_has_window (applet)) {
 		menu_x += applet->allocation.x;
 		menu_y += applet->allocation.y;
 	}
@@ -672,7 +672,7 @@ applet_show_menu (AppletInfo     *info,
 	gtk_menu_set_screen (GTK_MENU (info->menu),
 			     gtk_window_get_screen (GTK_WINDOW (panel_widget->toplevel)));
 
-	if (!GTK_WIDGET_REALIZED (info->menu))
+	if (!gtk_widget_get_realized (info->menu))
 		gtk_widget_show (info->menu);
 
 	gtk_menu_popup (GTK_MENU (info->menu),
@@ -692,7 +692,7 @@ applet_do_popup_menu (GtkWidget      *widget,
 	if (panel_applet_is_in_drag ())
 		return FALSE;
 
-	if (info->type == PANEL_OBJECT_BONOBO)
+	if (info->type == PANEL_OBJECT_APPLET)
 		return FALSE;
 
 	applet_show_menu (info, event);
@@ -753,7 +753,7 @@ panel_applet_destroy (GtkWidget  *widget,
 		}
 	}
 
-	if (info->type != PANEL_OBJECT_BONOBO)
+	if (info->type != PANEL_OBJECT_APPLET)
 		panel_lockdown_notify_remove (G_CALLBACK (panel_applet_recreate_menu),
 					      info);
 
@@ -872,6 +872,7 @@ panel_applet_stop_loading (const char *id)
 static gboolean
 panel_applet_load_idle_handler (gpointer dummy)
 {
+	PanelObjectType    applet_type;
 	PanelAppletToLoad *applet = NULL;
 	PanelToplevel     *toplevel = NULL;
 	PanelWidget       *panel_widget;
@@ -918,8 +919,16 @@ panel_applet_load_idle_handler (gpointer dummy)
 			applet->position = -1;
 	}
 
-	switch (applet->type) {
-	case PANEL_OBJECT_BONOBO:
+	/* We load applets asynchronously, so we specifically don't call
+	 * panel_applet_stop_loading() for this type. However, in case of
+	 * failure during the load, we might call panel_applet_stop_loading()
+	 * synchronously, which will make us lose the content of the applet
+	 * variable. So we save the type to be sure we always ignore the
+	 * applets. */
+	applet_type = applet->type;
+
+	switch (applet_type) {
+	case PANEL_OBJECT_APPLET:
 		panel_applet_frame_load_from_gconf (
 					panel_widget,
 					applet->locked,
@@ -982,8 +991,8 @@ panel_applet_load_idle_handler (gpointer dummy)
 		break;
 	}
 
-	/* Only the bonobo applets will do a late stop_loading */
-	if (applet->type != PANEL_OBJECT_BONOBO)
+	/* Only the real applets will do a late stop_loading */
+	if (applet_type != PANEL_OBJECT_APPLET)
 		panel_applet_stop_loading (applet->id);
 
 	return TRUE;
@@ -1031,14 +1040,16 @@ panel_applet_compare (const PanelAppletToLoad *a,
 }
 
 void
-panel_applet_load_queued_applets (void)
+panel_applet_load_queued_applets (gboolean initial_load)
 {
 	if (!panel_applets_to_load) {
 		panel_applet_queue_initial_unhide_toplevels (NULL);
 		return;
-        } else {
-		/* Install a timeout to make sure we don't block the unhiding
-		 * because of an applet that doesn't load */
+	}
+
+	if (initial_load && panel_applets_to_load) {
+		/* Install a timeout to make sure we don't block the
+		 * unhiding because of an applet that doesn't load */
 		panel_applet_unhide_toplevels_timeout =
 			g_timeout_add_seconds (UNHIDE_TOPLEVELS_TIMEOUT_SECONDS,
 					       panel_applet_queue_initial_unhide_toplevels,
@@ -1049,7 +1060,16 @@ panel_applet_load_queued_applets (void)
 					      (GCompareFunc) panel_applet_compare);
 
 	if ( ! panel_applet_have_load_idle) {
-		g_idle_add (panel_applet_load_idle_handler, NULL);
+		/* on panel startup, we don't care about redraws of the
+		 * toplevels since they are hidden, so we give a higher
+		 * priority to loading of applets */
+		if (initial_load)
+			g_idle_add_full (G_PRIORITY_HIGH_IDLE,
+					 panel_applet_load_idle_handler,
+					 NULL, NULL);
+		else
+			g_idle_add (panel_applet_load_idle_handler, NULL);
+
 		panel_applet_have_load_idle = TRUE;
 	}
 }
@@ -1124,7 +1144,7 @@ panel_applet_save_position (AppletInfo *applet_info,
 
 	client  = panel_gconf_get_client ();
 
-	key_type = applet_info->type == PANEL_OBJECT_BONOBO ? PANEL_GCONF_APPLETS : PANEL_GCONF_OBJECTS;
+	key_type = applet_info->type == PANEL_OBJECT_APPLET ? PANEL_GCONF_APPLETS : PANEL_GCONF_OBJECTS;
 	
 	panel_widget = PANEL_WIDGET (applet_info->widget->parent);
 
@@ -1248,7 +1268,7 @@ panel_applet_register (GtkWidget       *applet,
 	
 	g_return_val_if_fail (applet != NULL && panel != NULL, NULL);
 
-	if ( ! GTK_WIDGET_NO_WINDOW (applet))
+	if (gtk_widget_get_has_window (applet))
 		gtk_widget_set_events (applet, (gtk_widget_get_events (applet) |
 						APPLET_EVENT_MASK) &
 				       ~( GDK_POINTER_MOTION_MASK |
@@ -1266,11 +1286,11 @@ panel_applet_register (GtkWidget       *applet,
 
 	g_object_set_data (G_OBJECT (applet), "applet_info", info);
 
-	if (type != PANEL_OBJECT_BONOBO)
+	if (type != PANEL_OBJECT_APPLET)
 		panel_lockdown_notify_add (G_CALLBACK (panel_applet_recreate_menu),
 					   info);
 
-	key = panel_gconf_full_key ((type == PANEL_OBJECT_BONOBO) ?
+	key = panel_gconf_full_key ((type == PANEL_OBJECT_APPLET) ?
 				     PANEL_GCONF_APPLETS : PANEL_GCONF_OBJECTS,
 				    id, "locked");
 	panel_gconf_notify_add_while_alive (key,
@@ -1314,7 +1334,7 @@ panel_applet_register (GtkWidget       *applet,
 	}
 
 	if (BUTTON_IS_WIDGET (applet) ||
-	    !GTK_WIDGET_NO_WINDOW (applet)) {
+	    gtk_widget_get_has_window (applet)) {
 		g_signal_connect (applet, "button_press_event",
 				  G_CALLBACK (applet_button_press),
 				  info);
@@ -1336,7 +1356,7 @@ panel_applet_register (GtkWidget       *applet,
 	size_change (info, panel);
 	back_change (info, panel);
 
-	if (type != PANEL_OBJECT_BONOBO)
+	if (type != PANEL_OBJECT_APPLET)
 		gtk_widget_grab_focus (applet);
 	else
 		gtk_widget_child_focus (applet, GTK_DIR_TAB_FORWARD);
@@ -1369,7 +1389,7 @@ panel_applet_can_freely_move (AppletInfo *applet)
 
 	client  = panel_gconf_get_client ();
 	
-	key_type = (applet->type == PANEL_OBJECT_BONOBO) ? PANEL_GCONF_APPLETS : PANEL_GCONF_OBJECTS;
+	key_type = (applet->type == PANEL_OBJECT_APPLET) ? PANEL_GCONF_APPLETS : PANEL_GCONF_OBJECTS;
        
 	key = panel_gconf_full_key (key_type, applet->id, "position");
 	if (!gconf_client_key_is_writable (client, key, NULL))
@@ -1398,7 +1418,7 @@ panel_applet_lockable (AppletInfo *applet)
 	
 	client  = panel_gconf_get_client ();
 	
-	key_type = (applet->type == PANEL_OBJECT_BONOBO) ? PANEL_GCONF_APPLETS : PANEL_GCONF_OBJECTS;
+	key_type = (applet->type == PANEL_OBJECT_APPLET) ? PANEL_GCONF_APPLETS : PANEL_GCONF_OBJECTS;
 
 	key = panel_gconf_full_key (key_type, applet->id, "locked");
 
